<%@include file="include/header.jsp"%>
<%!
//-----------------------------------------------
boolean checkParam(UserData data){
	// Check password only if there's a password updated.
	if (!isEmpty(data.passwd) && !isSha1Hex(data.passwd)) {
		if (!ParamTest.isValidPasswdLen(data.passwd)) {
			errList.add(ParamTest.ERR_PASSWD_LEN);
			return false;
		}

		if (!ParamTest.isValidPasswdChar(data.passwd)) {
			errList.add(ParamTest.ERR_PASSWD_CHAR);
			return false;
		}
	}

	// token.
	if (!isEmpty(data.token) && !ParamTest.isValidToken(data.token)) {
		errList.add(ParamTest.ERR_TOKEN_INVALID);
		return false;
	}

	return true;
}

//-----------------------------------------------
void update(UserDao dao){
	UserData data = new UserData();
	data.id = paramInt("id");
	data.passwd = paramString("passwd");
	data.policyId = paramInt("policyId");
	data.ftPolicyId = paramInt("ftPolicyId");
	data.expDate = paramString("expDate");
	data.token = paramString("token");
	data.description = paramString("description");

	// Only for manually created users.
	data.grpId = paramInt("grpId");

	// Validate and update it.
	if(checkParam(data) && dao.update(data)){
		succList.add("Data updated.");
	}
}

//-----------------------------------------------
void newToken(UserDao dao){
	UserData data = new UserData();
	data.id = paramInt("id");
	data.token = paramString("token");

	if(dao.newToken(data.id)){
		succList.add("Data updated.");
	}
}

//-----------------------------------------------
void addIp(UserDao dao){
	UserIpData data = new UserIpData();
	data.userId = paramInt("id");
	data.startIp = paramString("startIp");
	data.endIp = paramString("endIp");

	// Param validation.
	if (!isValidIp(data.startIp)) {
		errList.add("Invalid start IP.");
		return;
	}

	if (isNotEmpty(data.endIp) && !isValidIp(data.endIp)) {
		errList.add("Invalid end IP.");
		return;
	}

	if(dao.addIp(data)){
		succList.add("Data updated.");

		if(!new ConfigDao().selectOne().enableLogin){
			warnList.add("Authentication needs to be enabled.");
		}
	}
}

//-----------------------------------------------
void deleteIp(UserDao dao){
	if(dao.deleteIp(paramInt("ipId"))){
		succList.add("Data updated.");
	}
}
%>
<%
//-----------------------------------------------
// Set permission for this page.
permission.addAdmin();

//Check permission.
if(!checkPermission()){
	return;
}

// Create data access object.
UserDao dao = new UserDao();

// Action.
String actionFlag = paramString("actionFlag");
if(actionFlag.equals("update")){
	update(dao);
}
if(actionFlag.equals("newToken")){
	newToken(dao);
}
if(actionFlag.equals("addIp")){
	addIp(dao);
}
if(actionFlag.equals("deleteIp")){
	deleteIp(dao);
}

// Global.
UserData data = dao.selectOne(paramInt("id"));

// Get policy list.
List<PolicyData> gPolicyList = new PolicyDao().selectListAll();
List<GroupData> gGroupList = new GroupDao().selectListUserCreatedOnly();

// Active tab.
String tabActive0 = "";
String tabActive1 = "";

String showActive0 = "";
String showActive1 = "";

int tabIdx = paramInt("tabIdx");
if(tabIdx == 0){
	tabActive0 = " active";
	showActive0 = " show active";
}
else if(tabIdx == 1){
	tabActive1 = " active";
	showActive1 = " show active";
}
%>
<!-- Action info -->
<%@include file="include/ab-notify.jsp"%>
<!-- /Action info -->

<!-- Breadcrumb -->
<div class="container-fluid primary" style="margin-top:-5px;">
	<ol class="breadcrumb" style="margin-left:10px; margin-right:10px;">
		<li class="breadcrumb-item">USER</li>
		<li class="breadcrumb-item">USER</li>
		<li class="breadcrumb-item text-info">EDIT</li>
	</ol>
</div>
<!-- /Breadcrumb -->

<!-- Main content -->
<div class="container-fluid">

	<!-- Tab -->
	<div>
		<ul class="nav nav-tabs" style="margin-left:10px; margin-right:10px;">
			<li class="nav-item" onclick="javascript:$('#tabIdx').val(0);">
				<a class="nav-link<%= tabActive0%>" data-toggle="tab" href="#tab0">EDIT</a>
			</li>
			<li class="nav-item" onclick="javascript:$('#tabIdx').val(1);">
				<a class="nav-link<%= tabActive1%>" data-toggle="tab" href="#tab1">ADD IP</a>
			</li>
		</ul>
	</div>
	<!-- Tab -->

	<!-- Form -->
	<form action="<%= getPageName()%>" method="post">
		<input type="hidden" name="actionFlag" value="update">
		<input type="hidden" name="id" value="<%= data.id%>">
		<input type="hidden" name="ipId" value="">
		<input type="hidden" id="tabIdx" name="tabIdx" value="<%= tabIdx%>">
 
		<!-- Tab content -->
		<div id="myTabContent" class="tab-content">

			<!-- Edit -->
			<div class="tab-pane <%= showActive0%>" id="tab0">
				<div class="card bg-light m-2 expand-lg">
					<div class="card-body">
						<fieldset>
							<div class="form-group col-lg-8">
								<label class="col-form-label">Name</label>
								<input type="text" class="form-control" id="name" name="name" value="<%= data.name%>" disabled>
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">Password</label>
								<input type="password" class="form-control" id="passwd"
									name="passwd" value="<%= data.passwd%>">
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">Work-time Policy</label>
								<select class="form-control" id="policyId" name="policyId">
<%
for(PolicyData pd : gPolicyList){
	if(pd.id == data.policyId){
		printf("<option value='%s' selected>%s</option>\n", pd.id, pd.name);
	}
	else{
		printf("<option value='%s'>%s</option>\n", pd.id, pd.name);
	}
}
%>
								</select>
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">Free-time Policy</label>
								<select class="form-control" id="ftPolicyId" name="ftPolicyId">
<%
for(PolicyData pd : gPolicyList){
	if(pd.id == data.ftPolicyId){
		printf("<option value='%s' selected>%s</option>\n", pd.id, pd.name);
	}
	else{
		printf("<option value='%s'>%s</option>\n", pd.id, pd.name);
	}
}
%>
								</select>
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">Expiration Date</label>
								<input type="text" class="form-control" id="expDate" name="expDate" value="<%= data.getExpDate()%>">
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">
									Login Token
									<i class="fa fa-question-circle south-east"
										title="User identifier for the remote filtering agents of NxFilter."></i>
								</label>
								<input type="text" class="form-control" id="token" name="token" value="<%= data.token%>">
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">Group, Member of</label>
<%
if(data.ldapId > 0){
	out.println("<input type='text' class='form-control' id='loginToken' name='loginToken' value='");
	out.println(data.getGroupLine());
	out.println("'>");
}
else{
	out.println("<select class='form-control' id='grpId' name='grpId'>");
	out.println("<option value='0'>anon-grp");
	for(GroupData grp : gGroupList){
		if(grp.name.startsWith(data.getGroupLine())){
			printf("<option value='%s' selected>%s</option>\n", grp.id, grp.name);
		}
		else{
			printf("<option value='%s'>%s</option>\n", grp.id, grp.name);
		}
	}
	out.println("</select>");
}
%>
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">Description</label>
								<input type="text" class="form-control" id="description"
									name="description" value="<%= data.description%>">
							</div>
							<div class="form-group col-lg-8">
								<button type="button" class="btn btn-primary" onclick="javascript:actionUpdate(this.form);">Submit</button>
								<button type="button" class="btn btn-info" onclick="javascript:actionNewToken(this.form)">NEW TOKEN</button>
							</div>
						</fieldset>
					</div>
				</div>
			</div>
			<!-- /Edit -->

			<!-- Add IP -->
			<div class="tab-pane fade<%= showActive1%>" id="tab1">
				<div class="card bg-light m-2 expand-lg">
					<div class="card-body">
						<fieldset>
							<div class="form-group col-lg-8 text-secondary">
								You can associate an IP address or an IP address range to a user. If it is a single IP association,
								add 'Start IP' only.
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">Start IP</label>
								<input type="text" class="form-control" id="startIp"
									name="startIp">
							</div>
							<div class="form-group col-lg-8">
								<label class="col-form-label">End IP</label>
								<input type="text" class="form-control" id="endIp"
									name="endIp">
							</div>
							<div class="form-group col-lg-8">
								<button type="button" class="btn btn-primary" onclick="javascript:actionAddIp(this.form);">ADD IP</button>
							</div>

<%
for(int i = 0; i < data.ipList.size(); i++){

	out.println("<div class='form-group col-lg-8 row' style='padding-left: 30px'>");

	for(int k = 0; k < 4; k++){
		UserIpData uip = data.ipList.get(i);

		printf("<span class='domain-item'><a class='xlink' href='javascript:actionDeleteIp(%s)'>[x]</a> %s</span>", uip.id, uip.asString());

		if(++i >= data.ipList.size()){
			break;
		}
	}

	out.println("</div>");
}
%>
						</fieldset>
					</div>
				</div>
			</div>
			<!-- /Add IP -->

		</div>
		<!-- Tab content -->

	</form>
	<!-- /Form -->

</div>
<!-- /Main content -->

<%@include file="include/footer.jsp"%>

<script>
//-----------------------------------------------
// Restricts input for each element in the set of matched elements to the given inputFilter.
(function($) {
	$.fn.inputFilter = function(inputFilter){
		return this.on("input keydown keyup mousedown mouseup select contextmenu drop", function(){
			if (inputFilter(this.value)){
				this.oldValue = this.value;
				this.oldSelectionStart = this.selectionStart;
				this.oldSelectionEnd = this.selectionEnd;
			} else if (this.hasOwnProperty("oldValue")){
				this.value = this.oldValue;
				this.setSelectionRange(this.oldSelectionStart, this.oldSelectionEnd);
			} else {
				this.value = "";
			}
		});
	};
}(jQuery));

// Install input filters.
$("#startIp").inputFilter(function(value){
	if(value == ""){
		return true;
	}

	return /^[\d\.]*$/.test(value);
});
$("#endIp").inputFilter(function(value){
	if(value == ""){
		return true;
	}

	return /^[\d\.]*$/.test(value);
});

//-----------------------------------------------
var dateToDisable = new Date();
jQuery("#expDate").datetimepicker({
	format: "<%= getGuiDateFormatForPicker()%> H:i",
	step: 1,
	beforeShowDay: function(date) {
		if (date.getTime() < dateToDisable.getTime()) {
			return [false, ""]
		}

		return [true, ""];
	}
});

//-----------------------------------------------
function actionNewToken(form){
	form.actionFlag.value = "newToken";
	form.submit();
}

//-----------------------------------------------
function actionUpdate(form){
	form.actionFlag.value = "update";
	form.submit();
}

//-----------------------------------------------
function actionAddIp(form){
	form.actionFlag.value = "addIp";
	form.submit();
}

//-----------------------------------------------
function actionDeleteIp(ipId){
	form = document.forms[0];
	form.actionFlag.value = "deleteIp";
	form.ipId.value = ipId;
	form.submit();
}
</script>
